%
%   PKEQNS_RampB_NOFDBK.M   Point Kinetics Equations for linearly varying z(t)
%                           for the Blade of Interest (BOI) with NO Feedbacks
%
%   This function file is called by ode15s to solve the linear point kinetics eqns.
%   (i.e. there are no feedbacks present in this simulation) for the case of a 
%   linearly varying z(t) due to a blade movement, and constant neutron source, Q.  
%   In particular, the BOI varies linearly until a specifc blade height is reached, 
%   and then it remains fixed at the zloc(2) location until the end of the simulation.  
%   Note that the equations have been normalized so that the neutron amplitude 
%   represents power in watts. 
%
%   Some inputs:
%   rate is the blade speed in inches/sec
%   zloc contains the start and end locations for the BOI (inches withdrawn),
%     where the relative values of zloc(1) and zloc(2) determine if the blade is 
%     being removed or inserted
%   BOI & yr identify the blade of interest and the year of the blade worth 
%     evaluation to use in the simulation (note: BOI = 5 for the RegBlade).  These
%     are used within the bworth function to obtain the integral worth of the BOI at
%     the given z location.
%
%   Written by  J. R. White, UMass-Lowell  (last update: March 2018)
%

      function xp = pkeqns_rampb_nofdbk(t,x,rho0,Q,Be,Gt,B,lam,kappa,nu, ...
                                        rate,zloc,boi,yr)
%
%   get value of rho for current t using the BOI worth curve (assumes t starts at zero)
      speed = rate;  if zloc(2) < zloc(1), speed = -speed;  end
      z = zloc(1)+speed*t;  
      if speed > 0 
        if z > zloc(2), z = zloc(2);  end 
      else
        if z < zloc(2), z = zloc(2);  end 
      end
      rho = bworth(z,boi,yr)-bworth(zloc(1),boi,yr);  rho = rho/100; % rho(t) (Dk/k)
%
%   order of state vector ==>  x = [P C1 C2 C3 C4 C5 C6]'
      xp = zeros(length(x),1); 
      RHO = rho0+rho;      
      xp(1) = (1/Gt)*(RHO-Be)*x(1) + lam(1)*x(2) + lam(2)*x(3) + lam(3)*x(4)...
                                   + lam(4)*x(5) + lam(5)*x(6) + lam(6)*x(7)...
                                   + kappa/(Gt*nu)*Q;
      xp(2) = B(1)*x(1)/Gt - lam(1)*x(2);
      xp(3) = B(2)*x(1)/Gt - lam(2)*x(3);
      xp(4) = B(3)*x(1)/Gt - lam(3)*x(4);
      xp(5) = B(4)*x(1)/Gt - lam(4)*x(5);
      xp(6) = B(5)*x(1)/Gt - lam(5)*x(6);
      xp(7) = B(6)*x(1)/Gt - lam(6)*x(7);
%
%    end of function