%
%   RegBlade_Sim.M   Sample RegBlade simulation case for student use...
%
%   This file provides a test case where the RegBlade is moved to initiate
%   a reactor transient.  Here only two movements are used, but as many steps as 
%   desired can be added.  The magnitude, direction, and duration of each movement 
%   can also be easily adjusted...
%
%   The solve_step.m file is a script file that solves the point kinetics equations 
%   for a single step of the overall simulation. It adds information from the current
%   step to the rr = reactivity, tt = time, PP = power, and zz = RegBlade position
%   arrays.
%   
%   File prepared J. R. White, UMass-Lowell (last update: March 2018)
%

      clear all,  close all,  nfig = 0;
%%
%   define UMLRR-specific kinetics data and other parameters for the simulations
      [Be,B,Gt,lam,td,S,kappa,nu] = kinetics_data();
      tol  = 1e-5;  options = odeset('RelTol',tol); % error tolerance for ODE solver
      dt = 1.0;               % sampling time (sec)
      nlevel = 0.00;          % random noise level (random uncertainty in P(t) data)
      a = 1-nlevel;   b = 1+nlevel;  % upper and lower bounds on 'noisy' P(t)
%
      rho0 = 0;   Q = 0;      % assume critical and no source 
      Po = 1;                 % initial power level (magnitude not important here)
      Co = B*Po./(lam*Gt);    % initial precursor conc
      xo = [Po Co]';          % initial condition for state vector
      rate = 50/60;           % rate of RegBlade change (inches/sec)
      boi = 5;  yr = 'Jan2018';    % BOI = RegBlade using Jan. 2018 data 
%
%%
%   do a series of blade movements (nothing fancy, just repeat same section of code)
%
      tend = 0;  Poo = Po;  x = xo';   rhoend = rho0;   
      rr = [];  tt = [];  PP = [];  zz = [];  
%
      zlocs = [12 15];  thold = 2*60;    speed = rate;   solve_step    % Step #1
      zlocs = [15 10];  thold = 10*60;   speed = rate;   solve_step    % Step #2
%        Note : this sequence can be continued for as many steps as desired...
%
%   now plot the full sequence
      nfig = nfig+1;  figure(nfig)
      subplot(2,1,1),plot(tt/60,rr*100,'r-','LineWidth',2),grid on
      title('RegBlade\_Sim: Simulated \rho(t) and Blade Position vs Time')
      ylabel('Reactivtiy (%\Deltak/k)')
      range = axis;  range(1) = -0.001;  axis(range);
      subplot(2,1,2),plot(tt/60,zz,'b-','LineWidth',2),grid on
      xlabel('Time (min)'), ylabel('Blade Position (inches out)')
      range = axis;  range(1) = -0.001;  axis(range);
%
      nfig = nfig+1;  figure(nfig)
      subplot(2,1,1),plot(tt/60,PP/Poo,'r-','LineWidth',2),grid on
      title('RegBlade\_Sim: Simulated P(t) and Blade Position vs Time')
      ylabel('Normalized Power Level')
      range = axis;  range(1) = -0.001;  axis(range);
      subplot(2,1,2),plot(tt/60,zz,'b-','LineWidth',2),grid on
      xlabel('Time (min)'), ylabel('Blade Position (inches out)')
      range = axis;  range(1) = -0.001;  axis(range);
%
      nfig = nfig+1;  figure(nfig)
      plot(tt/60,PP/Poo,'r-','LineWidth',2),grid on
      title('RegBlade\_Sim: Simulated P(t) vs Time')
      xlabel('Time (min)'),ylabel('Normalized Power Level')
      range = axis;  range(1) = -0.001;  axis(range);
 
%%
%   now with P(t), let's generate measured rho(t) with inverse kinetics
      rhoinvn = invkin_sr(PP,tt,lam,Co,dt,Be,Gt,B);
      nfig = nfig+1;   figure(nfig)
      plot(tt/60,rhoinvn*100,'r.',tt/60,rr*100,'b--','LineWidth',2),grid
      title('RegBlade\_Sim:  Comparison of Actual and Measured \rho_{tot}(t)')
      xlabel('Time (min)'),ylabel('Reactivity  (%\Deltak/k)')
      range = axis;  range(1) = -0.001;  axis(range);
      legend('Computed \rho(t)','Input \rho(t)','Location','NorthEast')
%
%   end of program
